@@ -56,7 +56,7 @@ if((esc=strchr(pnt, '\\')))
 	}
 
 pnt2=pnt+len-1;
-ch=*pnt2;
+/* ch=*pnt2; */ /* scan-build : useless given loop below */
 
 for(i=0;i<len;i++)
 	{
@@ -1135,6 +1135,8 @@ GLOBALS->traces.dirty = 1;
 
 t=GLOBALS->traces.first;
 tsort=tsort_pnt=wave_alloca(sizeof(Trptr)*GLOBALS->traces.total);   
+memset(tsort_pnt, 0, sizeof(Trptr)*GLOBALS->traces.total);
+
 for(i=0;i<GLOBALS->traces.total;i++)
         {
         if(!t)
@@ -1174,6 +1176,8 @@ if((cptr) && (!groupsArePresent()))
 	int num_reduced = 0;
 	int j;
 
+	memset(tsort_reduced, 0, sizeof(Trptr)*GLOBALS->traces.total);
+
 	for(i=0;i<GLOBALS->traces.total;i++)
 	        {
 	        if(tsort[i]->flags & TR_GRP_BEGIN)
@@ -1276,7 +1280,7 @@ for(i=0;i<GLOBALS->traces.total;i++)
         }
 
 GLOBALS->traces.last=prev;
-prev->t_next=NULL;
+if(prev) { prev->t_next=NULL; } /* scan-build */
 
 return(1);
 }  
@@ -1470,7 +1474,7 @@ Trptr last_good = t;
 Trptr t2;
 int oc_cnt = 0;
 int underflow_sticky = 0;
-Trptr tkill_undeflow = NULL;
+/* Trptr tkill_undeflow = NULL; */ /* scan-build */
 
 while(t)
 	{
@@ -1495,10 +1499,12 @@ while(t)
 
 		if(oc_cnt < 0) 
 			{
+			/*
 			if(!underflow_sticky)
 				{
 				tkill_undeflow = t;
 				}
+			*/ /* scan-build */
 			underflow_sticky = 1;
 			}
 		}
