@@ -129,6 +129,7 @@ while(*p1 && *p2)
 	}
 
 if((*p1)||(*p2)) return(NULL);
+if((!n1)||(!n2)) return(NULL); /* scan-build : null pointer on strcpy below */
 
 while(pfxlen>1)	/* backup if matching a sequence like 20..24 where the 2 matches outside of the left bracket */
 	{
@@ -379,11 +380,10 @@ while(h[0])	/* should never exit through this point the way we set up histents w
 vadd=(vptr)calloc_2(1,sizeof(struct VectorEnt)+numextrabytes);
 vadd->time=MAX_HISTENT_TIME;
 for(i=0;i<=numextrabytes;i++) vadd->v[i]=AN_U; /* formerly 0x55 */
-vcurr->next=vadd;
+if(vcurr) { vcurr->next=vadd; } /* scan-build */
 regions++;
 
-bitvec=(bvptr)calloc_2(1,sizeof(struct BitVector)+
-		(regions*sizeof(vptr)));
+bitvec=(bvptr)calloc_2(1,sizeof(struct BitVector)+((regions-1)*sizeof(vptr))); /* ajb : found "regions" by manual inspection, changed to "regions-1" as array is already [1] */
 
 strcpy(bitvec->bvname=(char *)malloc_2(strlen(b->name)+1),b->name);
 bitvec->nbits=b->nnbits;
@@ -393,7 +393,7 @@ vcurr=vhead;
 for(i=0;i<regions;i++)
 	{
 	bitvec->vectors[i]=vcurr;
-	vcurr=vcurr->next;
+	if(vcurr) { vcurr=vcurr->next; } /* scan-build */
 	}
 
 return(bitvec);
@@ -681,6 +681,8 @@ struct Bits *b=NULL;
 int state = 0;
 unsigned int rows = 0;
 
+memset(ba, 0, sizeof(ba)); /* scan-build */
+
 while(1)
 {
 pnt=str;
@@ -936,6 +938,7 @@ if(!GLOBALS->vcd_explicit_zero_subscripts)	/* 0==yes, -1==no */
 	}
 
 n=(struct Node **)wave_alloca(len*sizeof(struct Node *));
+memset(n, 0, len*sizeof(struct Node *)); /* scan-build */
 
 if(!GLOBALS->autocoalesce_reversal)		/* normal case for MTI */
 	{
@@ -1378,7 +1381,10 @@ if(numptr)
  */
 
 #ifdef WAVE_USE_SIGCMP_INFINITE_PRECISION
-inline int sigcmp_2(char *s1, char *s2)
+#if __STDC_VERSION__ < 199901L
+inline
+#endif
+int sigcmp_2(char *s1, char *s2)
 {
 char *n1, *n2;
 unsigned char c1, c2;
@@ -1444,7 +1450,10 @@ for(;;)
 	}
 }
 #else
-inline int sigcmp_2(char *s1, char *s2)
+#if __STDC_VERSION__ < 199901L
+inline
+#endif
+int sigcmp_2(char *s1, char *s2)
 {
 unsigned char c1, c2;
 int u1, u2;
@@ -1614,6 +1623,12 @@ int s1_was_packed = HIER_DEPACK_ALLOC, s2_was_packed = HIER_DEPACK_ALLOC;
 int root1len=0, root2len=0;
 int l1, l2;
 
+if(!sym)
+	{
+	fprintf(stderr, "Internal error '%s' line %d, exiting.\n", __FILE__, __LINE__);
+	exit(255);
+	}
+
 if(!GLOBALS->vcd_explicit_zero_subscripts)	/* 0==yes, -1==no */
 	{
 	hier_delimeter2=GLOBALS->hier_delimeter;
@@ -1626,6 +1641,7 @@ if(!GLOBALS->vcd_explicit_zero_subscripts)	/* 0==yes, -1==no */
 if(!GLOBALS->autocoalesce_reversal)		/* normal case for MTI */
 	{
 	symhi=sym;
+	symlo=sym; /* scan-build */
 	while(sym)
 		{
 		symlo=sym;
@@ -1635,6 +1651,7 @@ if(!GLOBALS->autocoalesce_reversal)		/* normal case for MTI */
 	else				/* for verilog XL */
 	{
 	symlo=sym;
+	symhi=sym; /* scan-build */
 	while(sym)
 		{
 		symhi=sym;
@@ -2298,6 +2315,7 @@ int parsewavline(char *w, char *alias, int depth)
  prefix=(char *)wave_alloca(len+1);
  suffix=(char *)wave_alloca(len+1);
  new=(char *)wave_alloca(len+1);
+ memset(new, 0, len+1); /* scan-build */
 
  prefix_init = prefix;
  w2_init = new;
@@ -2551,7 +2569,7 @@ if((*w2=='#')||(*w2==':'))
 
 			if(lbrack)
 				{
-				int made = 0;
+				/* int made = 0; */ /* scan-build */
 				char *w3;
 				char *rbrack           = strrchr(w2,   ']');
 				char *rightmost_lbrack = strrchr(sp+1, '[');
@@ -2563,11 +2581,12 @@ if((*w2=='#')||(*w2==':'))
 					w3 = malloc_2(strlen(w2) + 1 + strlen(rightmost_lbrack+1) + 1);
 					sprintf(w3, "%s:%s", w2, rightmost_lbrack+1);
 
-					made = maketraces(w3, alias, 1);
+					/* made = */ maketraces(w3, alias, 1); /* scan-build */
 					free_2(w3);
 					}
 
-				if(0)	/* this is overkill for now with possible delay implications so commented out */
+#if 0
+				/* this is overkill for now with possible delay implications so commented out */
 				if(!made)
 					{
 					*lbrack = 0;
@@ -2578,6 +2597,7 @@ if((*w2=='#')||(*w2==':'))
 					maketraces(w3, alias, 1);
 					free_2(w3);
 					}
+#endif
 				}
 			}
 		}
@@ -3084,6 +3104,7 @@ int parsewavline_lx2(char *w, char *alias, int depth)
  prefix=(char *)wave_alloca(len+1);
  suffix=(char *)wave_alloca(len+1);
  new=(char *)wave_alloca(len+1);
+ new[0] = 0; /* scan-build : in case there are weird mode problems */
 
  prefix_init = prefix;
  w2_init = new;
