@@ -251,6 +251,11 @@ NULL, /* extload_inv_idcodes */
 /*
  * file.c
  */
+#if GTK_CHECK_VERSION(2,4,0)
+NULL, /* pFileChoose */
+NULL, /* pFileChooseFilterName */
+NULL, /* pPatternSpec */
+#endif
 0, /* fs_file_c_1 86 */
 NULL, /* fileselbox_text 87 */
 0, /* filesel_ok 88 */
@@ -952,6 +957,9 @@ NULL, /* void (*cleanup_treesearch_gtk1_c)(); */
 /*
  * treesearch_gtk2.c
  */
+#ifdef WAVE_GDK_QUARTZ
+NULL, /* dnd_helper_quartz */
+#endif
 NULL, /* treeopen_chain_head */
 NULL, /* treeopen_chain_curr */
 0, /* tree_dnd_begin */
@@ -1390,7 +1398,8 @@ void reload_into_new_context(void)
 {
  FILE *statefile;
  struct Global *new_globals, *setjmp_globals;
- gint tree_frame_x = -1, tree_frame_y = -1;
+ /* gint tree_frame_x = -1; */ /* scan-build */
+ gint tree_frame_y = -1;
  gdouble tree_vadj_value = 0.0;
  gdouble tree_hadj_value = 0.0;
  gdouble treeview_vadj_value = 0.0;
@@ -1462,7 +1471,7 @@ void reload_into_new_context(void)
 	if(vadj) tree_vadj_value = vadj->value;
 	if(hadj) tree_hadj_value = hadj->value;
 
-	tree_frame_x = (GLOBALS->gtk2_tree_frame)->allocation.width;
+	/* tree_frame_x = (GLOBALS->gtk2_tree_frame)->allocation.width; */ /* scan-build */
 	tree_frame_y = (GLOBALS->gtk2_tree_frame)->allocation.height;
 
 	/* lower signal set */
@@ -1793,6 +1802,9 @@ void reload_into_new_context(void)
  strcpy2_into_new_context(new_globals, &new_globals->tcl_init_cmd, &GLOBALS->tcl_init_cmd);
  strcpy2_into_new_context(new_globals, &new_globals->repscript_name, &GLOBALS->repscript_name);
  new_globals->repscript_period = GLOBALS->repscript_period;
+#if GTK_CHECK_VERSION(2,4,0)
+ strcpy2_into_new_context(new_globals, &new_globals->pFileChooseFilterName, &GLOBALS->pFileChooseFilterName);
+#endif
 
  /* vlist.c */
  if(GLOBALS->vlist_handle)
