@@ -250,6 +250,11 @@ int fgetmalloc_len; /* from fgetdynamic.c 86 */
 /*
  * file.c
  */
+#if GTK_CHECK_VERSION(2,4,0)
+GtkWidget *pFileChoose;
+char *pFileChooseFilterName;
+GPatternSpec *pPatternSpec;
+#endif
 GtkWidget *fs_file_c_1; /* from file.c 87 */
 char **fileselbox_text; /* from file.c 88 */
 char filesel_ok; /* from file.c 89 */
@@ -935,6 +940,9 @@ void (*cleanup_treesearch_gtk1_c)(); /* ...end of manual adds */
 /*
  * treesearch_gtk2.c
  */
+#ifdef WAVE_GDK_QUARTZ
+char *dnd_helper_quartz;
+#endif
 struct string_chain_t *treeopen_chain_head; /* from bitvec.c */
 struct string_chain_t *treeopen_chain_curr; /* from bitvec.c */
 char tree_dnd_begin; /* from treesearch_gtk2.c */
