@@ -531,6 +531,10 @@ if((!hash_kill) && (vcd_ids))
 	jrb_free_tree(vcd_ids);
 	vcd_ids = NULL;
 	}
+	else
+	{
+	hash_kill = 1; /* scan-build */
+	}
 
 while(!feof(f))
 	{
@@ -769,7 +773,7 @@ free(node_len_array); node_len_array = NULL;
 
 if(f != stdin) fclose(f);
 
-exit(0);
+return(0);
 }
 
 
@@ -786,7 +790,7 @@ printf(
 
 "Note that VCDFILE and FSTFILE are optional provided the\n"
 "--vcdname and --fstname options are specified.\n\n"
-"Report bugs to <bybell@nc.rr.com>.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 #else
 printf(
 "Usage: %s [OPTION]... [VCDFILE] [FSTFILE]\n\n"
@@ -798,7 +802,7 @@ printf(
 
 "Note that VCDFILE and FSTFILE are optional provided the\n"
 "--vcdname and --fstname options are specified.\n\n"
-"Report bugs to <bybell@nc.rr.com>.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 #endif
 
 exit(0);
