@@ -31,13 +31,12 @@
 #include <sys/types.h>
 #endif
 
-#if !defined _MSC_VER && !defined OS_X && defined WAVE_USE_GTK2
+#if !defined _MSC_VER && defined WAVE_USE_GTK2
 #define WAVE_USE_XID
 #else
 #undef WAVE_USE_XID
 #endif
 
-
 #ifdef HAVE_GETOPT_LONG
 #include <getopt.h>
 #else
@@ -301,7 +300,7 @@ SLIDEZOOM_OPT
 "Note that DUMPFILE is optional if the --dump or --nocli options are specified.\n"
 "SAVEFILE and RCFILE are always optional.\n\n"
 
-"Report bugs to <bybell@nc.rr.com>.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 
 exit(0);
 }
@@ -1287,7 +1286,7 @@ load_vcd:
                   GLOBALS->unoptimized_vcd_file_name = calloc_2(1,strlen(GLOBALS->loaded_file_name) + 1);
                   strcpy(GLOBALS->unoptimized_vcd_file_name, GLOBALS->loaded_file_name);  
                   optimize_vcd_file();
-                  is_vcd = 0;
+                  /* is_vcd = 0; */ /* scan-build */
 		  GLOBALS->optimize_vcd = 1;
                   goto loader_check_head;
         }
@@ -1767,7 +1766,7 @@ if(GLOBALS->use_toolbutton_interface)
                                           timebox,
                                           NULL,
 					  NULL,
-					  tb_pos++);
+					  tb_pos /* ++ */); /* scan-build */
 
 		GLOBALS->missing_file_toolbar = tb;
 		if(GLOBALS->loaded_file_type == MISSING_FILE)
