@@ -184,6 +184,9 @@ WV_MENU_MCNM,
 WV_MENU_MCANM,
 WV_MENU_MDPM,
 WV_MENU_SEP8,
+WV_MENU_SLE,
+WV_MENU_SRE,
+WV_MENU_SEP8B,
 WV_MENU_MWSON,
 WV_MENU_MLKLT, 
 WV_MENU_MLKRT, 
