@@ -229,6 +229,10 @@ static gboolean DNDDragMotionCB(
 
 	/* Note if source widget is the same as the target. */
 	same_widget = (src_widget == tar_widget) ? TRUE : FALSE;
+	if(same_widget)
+		{
+		/* nothing */
+		}
 
 	GLOBALS->std_dnd_tgt_on_signalarea = (tar_widget == GLOBALS->signalarea);
 	GLOBALS->std_dnd_tgt_on_wavearea = (tar_widget == GLOBALS->wavearea);
@@ -622,6 +626,20 @@ event[0].deviceid = GDK_CORE_POINTER;
 
 execute_rpc();
 
+#ifdef WAVE_USE_GTK2
+#ifdef WAVE_GDK_QUARTZ
+if(GLOBALS->dnd_helper_quartz)
+        {
+        char *dhq = g_malloc(strlen(GLOBALS->dnd_helper_quartz)+1);
+        strcpy(dhq, GLOBALS->dnd_helper_quartz);
+        free_2(GLOBALS->dnd_helper_quartz);
+        GLOBALS->dnd_helper_quartz = NULL;
+        DND_helper_quartz(dhq);
+        g_free(dhq);
+        }
+#endif   
+#endif
+
 if(GLOBALS->loaded_file_type == MISSING_FILE)
 	{
 	return(TRUE);
@@ -899,6 +917,8 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 
 	if(event->state&GDK_CONTROL_MASK)
 		{
+		if(t) /* scan-build */
+		  {
 		  if(IsGroupBegin(t) && IsSelected(t))
 		    {
 		      ClearGroupTraces(t);
@@ -911,6 +931,7 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 		    {
 		      t->flags ^= TR_HIGHLIGHT;
 		    }
+		  }
 		}
 	else
 	if((event->state&GDK_SHIFT_MASK)&&(GLOBALS->starting_unshifted_trace))
@@ -962,7 +983,7 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 			else
 			{
 			GLOBALS->starting_unshifted_trace = t;
-			t->flags |= TR_HIGHLIGHT;
+			if(t) { t->flags |= TR_HIGHLIGHT; }  /* scan-build */
 			}
 		}
 	/*	else if(!(t->flags & TR_HIGHLIGHT)) Ben Sferrazza suggested fix rather than a regular "else" */
@@ -977,7 +998,7 @@ else
 			t2 = t2->t_next;
 			}
 
-		t->flags |= TR_HIGHLIGHT;
+		if(t) { t->flags |= TR_HIGHLIGHT; } /* scan-build */
 		}
 
 	if(event->type == GDK_2BUTTON_PRESS)
