@@ -1346,7 +1346,7 @@ if(s)
 		{
 		is_bus = 1;
 		*lbrack = 0;
-		len = lbrack - s2;
+		/* len = lbrack - s2; */ /* scan-build */
 		}
 
 	names = calloc_2(delim_cnt+1, sizeof(char *));
@@ -1378,7 +1378,7 @@ if(s)
 			{
 			len = 8 + strlen(tcllist) + 1 + 1 + 1; /* "{netBus ...} " + trailing null char */
 	
-			pnt = s2;
+			/* pnt = s2; */ /* scan-build */
 			rpnt = malloc_2(len+1);
 			strcpy(rpnt, "{netBus ");
 			pnt2 = rpnt + 8;
@@ -1387,7 +1387,7 @@ if(s)
 			{
 			len = 5 + strlen(tcllist) + 1 + 1 + 1; /* "{net ...} " + trailing null char */
 	
-			pnt = s2;
+			/* pnt = s2; */ /* scan-build */
 			rpnt = malloc_2(len+1);
 			strcpy(rpnt, "{net ");
 			pnt2 = rpnt + 5;
@@ -1401,7 +1401,7 @@ if(s)
 			{
 			len = 15 + (len_value + 1) + strlen(tcllist) + 1 + 1 + 1; /* "{netBusValue 0x...} " + trailing null char */
 	
-			pnt = s2;
+			/* pnt = s2; */ /* scan-build */
 			rpnt = malloc_2(len+1);
 			sprintf(rpnt, "{netBusValue 0x%s ", opt_value);
 			pnt2 = rpnt + 15 + (len_value + 1);
@@ -1410,7 +1410,7 @@ if(s)
 			{
 			len = 10 + (len_value + 1) + strlen(tcllist) + 1 + 1 + 1; /* "{netValue ...} " + trailing null char */
 	
-			pnt = s2;
+			/* pnt = s2; */ /* scan-build */
 			rpnt = malloc_2(len+1);
 			sprintf(rpnt, "{netValue %s ", opt_value);
 			pnt2 = rpnt + 10 + (len_value + 1);
@@ -1570,7 +1570,7 @@ for(i=0;i<GLOBALS->num_rows_search_c_2;i++)
                                         {
                                         if(len) set_s_selected(t, 0);
                                         }
-                                len++;
+                                /* len++; */ /* scan-build : artifact of below being removed */
 				break; /* t=t->vec_chain; ...no longer needed because of for() loop above and handler in process_tcl_list() */
                                 }
                         }
@@ -1648,7 +1648,7 @@ while(t)
 						}
 						else
 						{
-						if(strcmp(str, first_str)) { coalesce_pass = 0; break; }
+						if((!first_str /*scan-build */) || strcmp(str, first_str)) { coalesce_pass = 0; break; }
 						}
 					}
 					else
@@ -1675,7 +1675,7 @@ while(t)
 					char *pr = strrchr(strr, '[');
 					int ridx = atoi(pr+1);
 
-					int first_str_len = strlen(first_str);
+					int first_str_len = strlen(first_str ? first_str : (first_str = strdup_2("INTERNAL_ERROR"))); /* : case added for scan-build */
 					char *newname = malloc_2(first_str_len + 40);
 
 					sprintf(newname, "%s[%d:%d]", first_str, lidx, ridx); /* this disappears in make_single_tcl_list_name() but might be used in future code */
@@ -2396,9 +2396,9 @@ char pch = 0;
 char *nxt_hd = s;
 char *pnt = s;
 char *path;
-char **url_list = calloc_2(1, sizeof(gchar *));
+char **url_list = g_malloc(sizeof(gchar *)); /* deliberate g_funcs() as context can swap out from under us */
 
-if(*pnt == '{') return(0); /* exit early if tcl list */
+if(*pnt == '{') { g_free(url_list); return(0); } /* exit early if tcl list */
 
 for(;;)
 	{
@@ -2410,7 +2410,7 @@ for(;;)
 			}
 
 		path = g_filename_from_uri(nxt_hd, NULL, NULL);
-		if(path) { url_list[url_cnt++] = path; url_list = realloc_2(url_list, (url_cnt+1) * sizeof(gchar *)); }
+		if(path) { url_list[url_cnt++] = path; url_list = g_realloc(url_list, (url_cnt+1) * sizeof(gchar *)); }
 		break;
 		}
 	else
@@ -2422,7 +2422,7 @@ for(;;)
 			*pnt = 0;
 
 			path = g_filename_from_uri(nxt_hd, NULL, NULL);
-			if(path) { url_list[url_cnt++] = path; url_list = realloc_2(url_list, (url_cnt+1) * sizeof(gchar *)); }
+			if(path) { url_list[url_cnt++] = path; url_list = g_realloc(url_list, (url_cnt+1) * sizeof(gchar *)); }
 			*pnt = sav;
 			}
 		pch = *pnt;
@@ -2463,7 +2463,7 @@ if(url_list)
 		g_free(url_list[i]);
 		}
 
-	free_2(url_list);
+	g_free(url_list);
 	}
 
 #endif
@@ -2585,8 +2585,6 @@ GLOBALS->enable_fast_exit = 1;
 
 if(objc > 1)
 	{
-	struct wave_script_args *wc = NULL;
-
 	for(i=1;i<objc;i++)
 		{
 		char *s = Tcl_GetString(objv[i]);
@@ -2603,12 +2601,6 @@ if(objc > 1)
 			{
 			GLOBALS->wave_script_args = w;
 			w->curr = w;
-			wc = w;
-			}
-			else
-			{
-			wc->next = w; /* we later really traverse through curr->next from the head pointer */
-			wc = w;
 			}
 		}
 
@@ -2829,7 +2821,7 @@ GLOBALS->interp = Tcl_CreateInterp();
 void make_tcl_interpreter(char *argv[])
 {
   int i;
-  char commandName[256];
+  char commandName[32768];
   GtkItemFactoryEntry *ife;
   int num_menu_items;
   int n = 0;
@@ -2837,6 +2829,30 @@ void make_tcl_interpreter(char *argv[])
 #ifndef WAVE_TCL_STUBIFY
   Tcl_FindExecutable(argv[0]);
 #endif
+#if (defined(__MACH__) && defined(__APPLE__))
+  {
+  uint32_t size = sizeof(commandName);
+  if(_NSGetExecutablePath(commandName, &size) == 0)
+	{
+	set_globals_interp(commandName, 0);
+	}
+	else
+	{
+	char *p = calloc_2(1, size+1);
+	size++;
+  	if(_NSGetExecutablePath(p, &size) == 0)
+		{
+		set_globals_interp(p, 0);
+		}
+		else
+		{
+		fprintf(stderr, "GTKWAVE | Problem with _NSGetExecutablePath, exiting.\n");
+		exit(255);
+		}
+	free_2(p);
+	}
+  }
+#else
 #ifdef WIN32
   if(!GetModulePathName(NULL, commandName, 256))
     n = -1 ;
@@ -2850,6 +2866,7 @@ void make_tcl_interpreter(char *argv[])
     commandName[n] = '\0' ;
   }
   set_globals_interp(commandName, 0);
+#endif
 
 #ifndef WAVE_TCL_STUBIFY
   if (TCL_OK != Tcl_Init(GLOBALS->interp)) 
