@@ -22,7 +22,7 @@
 
 #include "debug.h"
 
-#if !defined _MSC_VER && !defined OS_X && defined WAVE_USE_GTK2
+#if !defined _MSC_VER && defined WAVE_USE_GTK2
 
 static int plug_removed(GtkWidget *widget, gpointer data)
 {
@@ -95,7 +95,11 @@ if(split_point < 0)
 
 mainwindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 gtk_window_set_title(GTK_WINDOW(mainwindow), "TwinWave Initializing");
+#ifndef WAVE_GDK_QUARTZ
 gtk_widget_set_usize(GTK_WIDGET(mainwindow), 820, 800);
+#else
+gtk_widget_set_usize(GTK_WIDGET(mainwindow), 400,32); /* quartz doesn't retarget into mainwindow */
+#endif
 gtk_widget_show(mainwindow);
 
 gtk_signal_connect(GTK_OBJECT(mainwindow), "destroy", GTK_SIGNAL_FUNC(quit_callback), "WM destroy");
@@ -424,10 +428,6 @@ fprintf(stderr, "Sorry, this requires GTK+-2.0 or greater to run!\n");
 fprintf(stderr, "Sorry, this doesn't run under Win32!\n");
 #endif
 
-#ifdef OS_X
-fprintf(stderr, "Sorry, this doesn't run under OS_X!\n");
-#endif
-
 fprintf(stderr, "If you find that this program works on your platform, please report this to the maintainers.\n");
 
 return(255);
